## Links

Poetry publishing process:

- [Publishing](https://python-poetry.org/docs/libraries/);
- [Credentials](https://python-poetry.org/docs/repositories/#configuring-credentials);

Github actions:

- [Reference action for Poetry publishing](https://github.com/code-specialist/pypi-poetry-publish/blob/main/action.yaml);
